@@ -18,13 +18,8 @@
 
 */
 
-#include <KAboutData>
-
-#include <KLocalizedString>
-
 #include <QApplication>
 #include <QCommandLineParser>
-#include <QCommandLineOption>
 #include <QStandardPaths>
 
 #include "../src/libkdepim/ldap/ldapsearchdialog.h"
@@ -32,16 +27,12 @@
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
-    KAboutData aboutData(QStringLiteral("testldapsearchdialog"), i18n("Test LDapSearchDialog"), QStringLiteral("0.1"));
     QCommandLineParser parser;
     //We can't use it otherwise we need to call kbuilsyscoca in test mode too.
     //QStandardPaths::setTestModeEnabled(true);
-    KAboutData::setApplicationData(aboutData);
     parser.addVersionOption();
     parser.addHelpOption();
-    aboutData.setupCommandLine(&parser);
     parser.process(app);
-    aboutData.processCommandLine(&parser);
 
     KLDAP::LdapSearchDialog dlg;
     dlg.exec();
