@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2013 Montel Laurent <montel@kde.org>
+    Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -46,9 +46,9 @@ private:
     void slotTimerDone();
     int mProgressCount;
     KPixmapSequence mProgressPix;
-    QTimer *mProgressTimer;
-    ProgressIndicatorWidget *mIndicator;
-    bool mIsActive;
+    QTimer *mProgressTimer = nullptr;
+    ProgressIndicatorWidget *mIndicator = nullptr;
+    bool mIsActive = false;
 };
 
 class KDEPIM_EXPORT ProgressIndicatorWidget : public QLabel
